@@ -164,6 +164,20 @@ class TestSphere(unittest.TestCase):
         shifted = s.shift(gm.Vector3(-10, -10))
         self.assertEqual(shifted.center, gm.Vector3())
 
+        s = gm.Sphere(center=zeros(), radius=2.0)
+        s += mp.Vector3(5, 5)
+        self.assertEqual(s.center, mp.Vector3(5, 5))
+
+        s = gm.Sphere(center=zeros(), radius=2.0)
+        new_sphere = s + mp.Vector3(5, 5)
+        self.assertEqual(new_sphere.center, mp.Vector3(5, 5))
+        self.assertEqual(s.center, zeros())
+
+        s = gm.Sphere(center=zeros(), radius=2.0)
+        new_sphere = mp.Vector3(5, 5) + s
+        self.assertEqual(new_sphere.center, mp.Vector3(5, 5))
+        self.assertEqual(s.center, zeros())
+
     def test_info(self):
         # Sanity test to ensure that display_geometric_object_info is callable
         s = gm.Sphere(2)
@@ -199,13 +213,6 @@ class TestCylinder(unittest.TestCase):
         self.assertNotIn(gm.Vector3(2.0001, 0, 0), c)
         self.assertNotIn(gm.Vector3(10, 10, 10), c)
 
-    def test_missing_required_arg_throws(self):
-        c = gm.Cylinder(radius=2.0, height=4.0, center=None)
-
-        with self.assertRaises(ValueError) as ctx:
-            self.assertIn(zeros(), c)
-            self.assertIn("Vector3 is not initialized", ctx.exception)
-
     def test_wrong_type_exception(self):
         """Test for Issue 180"""
         with self.assertRaises(TypeError):
@@ -441,6 +448,11 @@ class TestVector3(unittest.TestCase):
         res = v.rotate_reciprocal(axis, 3, lattice)
         self.assertTrue(res.close(mp.Vector3(2.0, -2.262225009320625, -1.6977449770811563)))
 
+    def test_complex_norm(self):
+        # issue #722
+        v = mp.Vector3(1, 1j, 0)
+        self.assertAlmostEqual(v.norm(), math.sqrt(2))
+
 
 class TestLattice(unittest.TestCase):
 
