@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2015 Massachusetts Institute of Technology
+/* Copyright (C) 2005-2019 Massachusetts Institute of Technology
 %
 %  This program is free software; you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -30,8 +30,8 @@ using namespace std;
 
 namespace meep {
 
-// Write the parameters required to reconstruct the susceptibility (id, noise_amp (for noisy), omega_0,
-// gamma, no_omega_0_denominator)
+// Write the parameters required to reconstruct the susceptibility (id, noise_amp (for noisy),
+// omega_0, gamma, no_omega_0_denominator)
 void structure::write_susceptibility_params(h5file *file, const char *dname, int EorH) {
   // Get number of susceptibility params from first chunk, since all chunks will have
   // the same susceptibility list.
@@ -54,25 +54,53 @@ void structure::write_susceptibility_params(h5file *file, const char *dname, int
   }
 }
 
+void structure::dump_chunk_layout(const char *filename) {
+  // Write grid_volume info for each chunk so we can reconstruct chunk division from split_by_cost
+  size_t sz = num_chunks * 3;
+  realnum *origins = new realnum[sz];
+  size_t *nums = new size_t[sz];
+  memset(nums, 0, sizeof(size_t) * sz);
+  memset(origins, 0, sizeof(realnum) * sz);
+  for (int i = 0; i < num_chunks; ++i) {
+    int idx = i * 3;
+    LOOP_OVER_DIRECTIONS(gv.dim, d) {
+      origins[idx++] = chunks[i]->gv.origin_in_direction(d);
+      nums[i * 3 + ((int)d % 3)] = chunks[i]->gv.num_direction(d);
+    }
+  }
+  h5file file(filename, h5file::WRITE, true);
+  file.create_data("gv_origins", 1, &sz);
+  if (am_master()) {
+    size_t gv_origins_start = 0;
+    file.write_chunk(1, &gv_origins_start, &sz, origins);
+  }
+  file.create_data("gv_nums", 1, &sz);
+  if (am_master()) {
+    size_t nums_start = 0;
+    file.write_chunk(1, &nums_start, &sz, nums);
+  }
+  delete[] origins;
+  delete[] nums;
+}
+
 void structure::dump(const char *filename) {
-  if (!quiet)
-    master_printf("creating epsilon output file \"%s\"...\n", filename);
+  if (verbosity > 0) master_printf("creating epsilon output file \"%s\"...\n", filename);
 
   // make/save a num_chunks x NUM_FIELD_COMPONENTS x 5 array counting
   // the number of entries in the chi1inv array for each chunk.
-  size_t *num_chi1inv_ = new size_t[num_chunks*NUM_FIELD_COMPONENTS*5];
-  memset(num_chi1inv_, 0, sizeof(size_t)*size_t(num_chunks*NUM_FIELD_COMPONENTS*5));
+  size_t *num_chi1inv_ = new size_t[num_chunks * NUM_FIELD_COMPONENTS * 5];
+  memset(num_chi1inv_, 0, sizeof(size_t) * size_t(num_chunks * NUM_FIELD_COMPONENTS * 5));
   size_t my_ntot = 0;
-  for (int i=0; i<num_chunks; i++)
+  for (int i = 0; i < num_chunks; i++)
     if (chunks[i]->is_mine()) {
       size_t ntot = chunks[i]->gv.ntot();
       for (int c = 0; c < NUM_FIELD_COMPONENTS; ++c)
         for (int d = 0; d < 5; ++d)
           if (chunks[i]->chi1inv[c][d])
-            my_ntot += (num_chi1inv_[(i*NUM_FIELD_COMPONENTS + c)*5 + d] = ntot);
+            my_ntot += (num_chi1inv_[(i * NUM_FIELD_COMPONENTS + c) * 5 + d] = ntot);
     }
-  size_t *num_chi1inv = new size_t[num_chunks*NUM_FIELD_COMPONENTS*5];
-  sum_to_master(num_chi1inv_, num_chi1inv, num_chunks*NUM_FIELD_COMPONENTS*5);
+  size_t *num_chi1inv = new size_t[num_chunks * NUM_FIELD_COMPONENTS * 5];
+  sum_to_master(num_chi1inv_, num_chi1inv, num_chunks * NUM_FIELD_COMPONENTS * 5);
   delete[] num_chi1inv_;
 
   // determine total dataset size and offset of this process's data
@@ -83,21 +111,20 @@ void structure::dump(const char *filename) {
   size_t dims[3] = {(size_t)num_chunks, NUM_FIELD_COMPONENTS, 5};
   size_t start[3] = {0, 0, 0};
   file.create_data("num_chi1inv", 3, dims);
-  if (am_master())
-    file.write_chunk(3, start, dims, num_chi1inv);
+  if (am_master()) file.write_chunk(3, start, dims, num_chi1inv);
   delete[] num_chi1inv;
 
   // write the data
   file.create_data("chi1inv", 1, &ntotal);
-  for (int i=0; i<num_chunks; i++)
+  for (int i = 0; i < num_chunks; i++)
     if (chunks[i]->is_mine()) {
-        size_t ntot = chunks[i]->gv.ntot();
-        for (int c = 0; c < NUM_FIELD_COMPONENTS; ++c)
-          for (int d = 0; d < 5; ++d)
-            if (chunks[i]->chi1inv[c][d]) {
-              file.write_chunk(1, &my_start, &ntot, chunks[i]->chi1inv[c][d]);
-              my_start += ntot;
-            }
+      size_t ntot = chunks[i]->gv.ntot();
+      for (int c = 0; c < NUM_FIELD_COMPONENTS; ++c)
+        for (int d = 0; d < 5; ++d)
+          if (chunks[i]->chi1inv[c][d]) {
+            file.write_chunk(1, &my_start, &ntot, chunks[i]->chi1inv[c][d]);
+            my_start += ntot;
+          }
     }
 
   // Get the sizes of susceptibility lists for chiP[E_stuff] and chiP[H_stuff]
@@ -144,9 +171,7 @@ void structure::dump(const char *filename) {
         if (sus) {
           for (int c = 0; c < NUM_FIELD_COMPONENTS; ++c) {
             for (int d = 0; d < 5; ++d) {
-              if (sus->sigma[c][d]) {
-                my_num_sigmas[ft][i] += 1;
-              }
+              if (sus->sigma[c][d]) { my_num_sigmas[ft][i] += 1; }
             }
           }
         }
@@ -178,12 +203,8 @@ void structure::dump(const char *filename) {
   size_t num_E_sigmas = 0;
   size_t num_H_sigmas = 0;
   for (int i = 0; i < num_chunks; ++i) {
-    if (num_sigmas[E_stuff][i] != 0) {
-      num_E_sigmas = num_sigmas[E_stuff][i];
-    }
-    if (num_sigmas[H_stuff][i] != 0) {
-      num_H_sigmas = num_sigmas[H_stuff][i];
-    }
+    if (num_sigmas[E_stuff][i] != 0) { num_E_sigmas = num_sigmas[E_stuff][i]; }
+    if (num_sigmas[H_stuff][i] != 0) { num_H_sigmas = num_sigmas[H_stuff][i]; }
   }
 
   // Allocate space for component and direction of non-null sigmas
@@ -205,9 +226,7 @@ void structure::dump(const char *filename) {
       int j = 0;
       bool done = false;
       for (int i = 0; i < num_chunks; ++i) {
-        if (done) {
-          break;
-        }
+        if (done) { break; }
         if (chunks[i]->is_mine()) {
           susceptibility *sus = chunks[i]->chiP[ft];
           if (sus) {
@@ -317,8 +336,7 @@ susceptibility *make_sus_list_from_params(h5file *file, int rank, size_t dims[3]
         sus->set_id(id);
         res = sus;
       }
-      if (sus->next)
-        sus = sus->next;
+      if (sus->next) sus = sus->next;
     }
     else if (num_params == 5) {
       // This is a noisy_lorentzian_susceptibility and the next 5 values in the dataset
@@ -334,18 +352,46 @@ susceptibility *make_sus_list_from_params(h5file *file, int rank, size_t dims[3]
       double gamma = noisy_lorentzian_params[3];
       bool no_omega_0_denominator = (bool)noisy_lorentzian_params[4];
       if (sus) {
-        sus->next = new noisy_lorentzian_susceptibility(noise_amp, omega_0, gamma, no_omega_0_denominator);
+        sus->next =
+            new noisy_lorentzian_susceptibility(noise_amp, omega_0, gamma, no_omega_0_denominator);
         sus->next->ntot = ntot;
         sus->next->set_id(id);
       }
       else {
-        sus = new noisy_lorentzian_susceptibility(noise_amp, omega_0, gamma, no_omega_0_denominator);
+        sus =
+            new noisy_lorentzian_susceptibility(noise_amp, omega_0, gamma, no_omega_0_denominator);
         sus->ntot = ntot;
         sus->set_id(id);
         res = sus;
       }
-      if (sus->next)
-        sus = sus->next;
+      if (sus->next) sus = sus->next;
+    }
+    else if (num_params == 8) {
+      // This is a gyrotropic_susceptibility and the next 8 values in the dataset
+      // are id, bias.x, bias.y, bias.z, omega_0, gamma, alpha, and model.
+      size_t gyro_susc_dims[3] = {8, 0, 0};
+      realnum gyro_susc_params[8];
+      file->read_chunk(rank, &start, gyro_susc_dims, gyro_susc_params);
+      start += gyro_susc_dims[0];
+
+      int id = (int)gyro_susc_params[0];
+      const vec bias(gyro_susc_params[1], gyro_susc_params[2], gyro_susc_params[3]);
+      const double omega_0 = gyro_susc_params[4];
+      const double gamma = gyro_susc_params[5];
+      const double alpha = gyro_susc_params[6];
+      const gyrotropy_model model = (gyrotropy_model)gyro_susc_params[7];
+      if (sus) {
+        sus->next = new gyrotropic_susceptibility(bias, omega_0, gamma, alpha, model);
+        sus->next->ntot = ntot;
+        sus->next->set_id(id);
+      }
+      else {
+        sus = new gyrotropic_susceptibility(bias, omega_0, gamma, alpha, model);
+        sus->ntot = ntot;
+        sus->set_id(id);
+        res = sus;
+      }
+      if (sus->next) sus = sus->next;
     }
     else {
       abort("Invalid number of susceptibility parameters in structure::load");
@@ -359,8 +405,7 @@ void structure::set_chiP_from_file(h5file *file, const char *dataset, field_type
   size_t dims[3] = {0, 0, 0};
 
   file->read_size(dataset, &rank, dims, 1);
-  if (rank != 1)
-    abort("inconsistent data size in structure::load");
+  if (rank != 1) abort("inconsistent data size in structure::load");
 
   if (dims[0] != 0) {
     for (int i = 0; i < num_chunks; ++i) {
@@ -369,44 +414,103 @@ void structure::set_chiP_from_file(h5file *file, const char *dataset, field_type
   }
 }
 
+void structure::load_chunk_layout(const char *filename, boundary_region &br) {
+  // Load chunk grid_volumes from a file
+  h5file file(filename, h5file::READONLY, true);
+  size_t sz = num_chunks * 3;
+  realnum *origins = new realnum[sz];
+  memset(origins, 0, sizeof(realnum) * sz);
+  size_t *nums = new size_t[sz];
+  memset(nums, 0, sizeof(size_t) * sz);
+
+  int origins_rank;
+  size_t origins_dims;
+  file.read_size("gv_origins", &origins_rank, &origins_dims, 1);
+  if (origins_rank != 1 || origins_dims != sz) { abort("chunk mismatch in structure::load"); }
+  if (am_master()) {
+    size_t gv_origins_start = 0;
+    file.read_chunk(1, &gv_origins_start, &origins_dims, origins);
+  }
+  file.prevent_deadlock();
+  broadcast(0, origins, sz);
+
+  int nums_rank;
+  size_t nums_dims;
+  file.read_size("gv_nums", &nums_rank, &nums_dims, 1);
+  if (nums_rank != 1 || nums_dims != sz) { abort("chunk mismatch in structure::load"); }
+  if (am_master()) {
+    size_t gv_nums_start = 0;
+    file.read_chunk(1, &gv_nums_start, &nums_dims, nums);
+  }
+  file.prevent_deadlock();
+  broadcast(0, nums, sz);
+
+  std::vector<grid_volume> gvs;
+  // Populate a vector with the new grid_volumes
+  for (int i = 0; i < num_chunks; ++i) {
+    int idx = i * 3;
+    grid_volume new_gv = gv;
+    vec new_origin(new_gv.dim);
+    LOOP_OVER_DIRECTIONS(gv.dim, d) {
+      new_origin.set_direction(d, origins[idx++]);
+      new_gv.set_num_direction(d, nums[i * 3 + ((int)d % 3)]);
+    }
+    new_gv.set_origin(new_origin);
+    gvs.push_back(new_gv);
+  }
+
+  load_chunk_layout(gvs, br);
+
+  delete[] origins;
+  delete[] nums;
+}
+
+void structure::load_chunk_layout(const std::vector<grid_volume> &gvs, boundary_region &br) {
+  // Recreate the chunks with the new grid_volumes
+  for (int i = 0; i < num_chunks; ++i) {
+    if (chunks[i]->refcount-- <= 1) delete chunks[i];
+    int proc = i * count_processors() / num_chunks;
+    chunks[i] = new structure_chunk(gvs[i], v, Courant, proc);
+    br.apply(this, chunks[i]);
+  }
+  check_chunks();
+}
+
 void structure::load(const char *filename) {
   h5file file(filename, h5file::READONLY, true);
 
-  if (!quiet)
-    master_printf("reading epsilon from file \"%s\"...\n", filename);
+  if (verbosity > 0) master_printf("reading epsilon from file \"%s\"...\n", filename);
 
   // make/save a num_chunks x NUM_FIELD_COMPONENTS x 5 array counting
   // the number of entries in the chi1inv array for each chunk.
-  size_t *num_chi1inv = new size_t[num_chunks*NUM_FIELD_COMPONENTS*5];
+  size_t *num_chi1inv = new size_t[num_chunks * NUM_FIELD_COMPONENTS * 5];
   int rank;
   size_t dims[3], _dims[3] = {(size_t)num_chunks, NUM_FIELD_COMPONENTS, 5};
   size_t start[3] = {0, 0, 0};
   file.read_size("num_chi1inv", &rank, dims, 3);
   if (rank != 3 || _dims[0] != dims[0] || _dims[1] != dims[1] || _dims[2] != dims[2])
     abort("chunk mismatch in structure::load");
-  if (am_master())
-    file.read_chunk(3, start, dims, num_chi1inv);
+  if (am_master()) file.read_chunk(3, start, dims, num_chi1inv);
 
   file.prevent_deadlock();
-  broadcast(0, num_chi1inv, dims[0]*dims[1]*dims[2]);
+  broadcast(0, num_chi1inv, dims[0] * dims[1] * dims[2]);
 
   changing_chunks();
 
   // allocate data as needed and check sizes
   size_t my_ntot = 0;
-  for (int i=0; i<num_chunks; i++)
+  for (int i = 0; i < num_chunks; i++)
     if (chunks[i]->is_mine()) {
       size_t ntot = chunks[i]->gv.ntot();
       for (int c = 0; c < NUM_FIELD_COMPONENTS; ++c)
         for (int d = 0; d < 5; ++d) {
-          size_t n = num_chi1inv[(i*NUM_FIELD_COMPONENTS + c)*5 + d];
+          size_t n = num_chi1inv[(i * NUM_FIELD_COMPONENTS + c) * 5 + d];
           if (n == 0) {
             delete[] chunks[i]->chi1inv[c][d];
             chunks[i]->chi1inv[c][d] = NULL;
           }
           else {
-            if (n != ntot)
-              abort("grid size mismatch %zd vs %zd in structure::load", n, ntot);
+            if (n != ntot) abort("grid size mismatch %zd vs %zd in structure::load", n, ntot);
             chunks[i]->chi1inv[c][d] = new realnum[ntot];
             my_ntot += ntot;
           }
@@ -419,17 +523,16 @@ void structure::load(const char *filename) {
 
   // read the data
   file.read_size("chi1inv", &rank, dims, 1);
-  if (rank != 1 || dims[0] != ntotal)
-    abort("inconsistent data size in structure::load");
-  for (int i=0; i<num_chunks; i++)
+  if (rank != 1 || dims[0] != ntotal) abort("inconsistent data size in structure::load");
+  for (int i = 0; i < num_chunks; i++)
     if (chunks[i]->is_mine()) {
-        size_t ntot = chunks[i]->gv.ntot();
-        for (int c = 0; c < NUM_FIELD_COMPONENTS; ++c)
-          for (int d = 0; d < 5; ++d)
-            if (chunks[i]->chi1inv[c][d]) {
-              file.read_chunk(1, &my_start, &ntot, chunks[i]->chi1inv[c][d]);
-              my_start += ntot;
-            }
+      size_t ntot = chunks[i]->gv.ntot();
+      for (int c = 0; c < NUM_FIELD_COMPONENTS; ++c)
+        for (int d = 0; d < 5; ++d)
+          if (chunks[i]->chi1inv[c][d]) {
+            file.read_chunk(1, &my_start, &ntot, chunks[i]->chi1inv[c][d]);
+            my_start += ntot;
+          }
     }
   // Create susceptibilites from params datasets
   set_chiP_from_file(&file, "E_params", E_stuff);
@@ -464,9 +567,7 @@ void structure::load(const char *filename) {
     int rank = 0;
     size_t dims[] = {0, 0, 0};
     file.read_size("num_sigmas", &rank, dims, 1);
-    if (dims[0] != (size_t)num_chunks * 2) {
-      abort("inconsistent data size in structure::load");
-    }
+    if (dims[0] != (size_t)num_chunks * 2) { abort("inconsistent data size in structure::load"); }
     if (am_master()) {
       size_t start = 0;
       size_t count = num_chunks;
@@ -485,9 +586,7 @@ void structure::load(const char *filename) {
   size_t nsig[2] = {0, 0};
   for (int ft = 0; ft < 2; ++ft) {
     for (int i = 0; i < num_chunks; ++i) {
-      if (num_sigmas[ft][i] != 0) {
-        nsig[ft] = num_sigmas[ft][i];
-      }
+      if (num_sigmas[ft][i] != 0) { nsig[ft] = num_sigmas[ft][i]; }
     }
   }
 
@@ -522,7 +621,7 @@ void structure::load(const char *filename) {
     for (int i = 0; i < num_chunks; ++i) {
       for (int c = 0; c < NUM_FIELD_COMPONENTS; ++c) {
         for (int d = 0; d < 5; ++d) {
-          susceptibility * sus = chunks[i]->chiP[ft];
+          susceptibility *sus = chunks[i]->chiP[ft];
           while (sus) {
             for (size_t j = 0; j < nsig[ft] * 2; j += 2) {
               int _c = sigma_cd[ft][j];
@@ -552,9 +651,7 @@ void structure::load(const char *filename) {
               size_t start = 0;
               while (sus) {
                 size_t count = chunks[i]->gv.ntot();
-                if (sus->sigma[c][d]) {
-                  delete[] sus->sigma[c][d];
-                }
+                if (sus->sigma[c][d]) { delete[] sus->sigma[c][d]; }
                 sus->sigma[c][d] = new realnum[count];
                 sus->trivial_sigma[c][d] = false;
                 file.read_chunk(rank, &start, &count, sus->sigma[c][d]);
